// This may look like C code, but it is really -*- C++ -*-
//
// Copyright Bob Friesenhahn, 1999
//
// Simplified includes for Magick++.
// Inclusion of this header is sufficient to use all Magick++ APIs.
//
#ifndef MagickPlusPlus_Header
#include <Magick++/Image.h>
#include <Magick++/STL.h>
#define MagickPlusPlus_Header
#endif // MagickPlusPlus_Header
